<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://profiles.wordpress.org/webbuilder143/
 * @since      1.0.0
 *
 * @package    Wb_Custom_Product_Tabs_For_Woocommerce
 * @subpackage Wb_Custom_Product_Tabs_For_Woocommerce/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Wb_Custom_Product_Tabs_For_Woocommerce
 * @subpackage Wb_Custom_Product_Tabs_For_Woocommerce/admin
 * @author     Web Builder 143 <webbuilder143@gmail.com>
 */
class Wb_Custom_Product_Tabs_For_Woocommerce_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wb-custom-product-tabs-for-woocommerce-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wb-custom-product-tabs-for-woocommerce-admin.js', array( 'jquery' ), $this->version, false );
		wp_localize_script($this->plugin_name, 'wb_custom_tabs_params', array(
			'msgs'=>array(
				'untitled'=>__('Untitled'),
				'no_data'=>__('No data'),
				'sure'=>__('Are you sure?'),
			)		
		));
	}


	/**
	 *	@since 1.0.0
	 *	Adding tabs to woocomerce product section
	 */
	public function product_data_tabs($tabs)
	{
		$tabs['wb_custom_tabs']= array(
			'label'    => __( 'Custom Tabs' ),
			'target'   => 'wb_custom_tabs',
			'class'    => array( 'hide_if_grouped' ),
			'priority' =>110,
		);
		return $tabs;
	}

	/**
	 *	@since 1.0.0
	 *	Render product tab form in admin section
	 */
	public function product_data_panels()
	{
		global $post;
		$product=wc_get_product($post);

		$tabs=Wb_Custom_Product_Tabs_For_Woocommerce::get_product_tabs($product);

		include 'views/product_data_panels.php';
	}

	/**
	 *	@since 1.0.0
	 *	Sanitize product tab data before saving
	 */
	private function sanitize_tab_input($arr)
	{
		$out=array();
		foreach($arr as $ar)
		{
			$title=sanitize_text_field(trim($ar['title']));
			$content=wp_kses_post(trim($ar['content']));
			$position=absint($ar['position']);
			if($title!="" && $content!="") //skip empty tabs
			{
				$out[]=array(
					'title'=>$title,
					'content'=>$content,
					'tab_type'=>'local',
					'position'=>$position
				);
			}			
		}
		return $out;
	}

	/**
	 *	@since 1.0.0
	 *	Save product tab data to database
	 */
	public function process_product_meta($post_id, $post)
	{
		if(empty($post_id))
		{
			return;
		}
		$product=wc_get_product($post_id);
		$product->update_meta_data('wb_custom_tabs', $this->sanitize_tab_input($_POST['wb_tab']));
        $product->save();
	}

	/**
	 *	@since 1.0.2
	 *	Register global tabs as custom post type
	 */
	public function register_global_tabs()
	{
		register_post_type(WB_TAB_POST_TYPE,
	        array(
	            'labels' => array(
	                'name' => __('Product tabs'),
	                'singular_name' => __('Product tab')
	            ),
	            'show_ui' => true,
	            'has_archive' => false,
	            'taxonomies'   => array( 'product_cat',  'product_tag' ),
	            'show_in_menu' => 'edit.php?post_type=product'
	        )
	    );
	}

	/**
	 *	@since 1.0.2
	 *	Save metabox data
	 */
	public function save_meta_box_data($post_id)
	{
		if(array_key_exists('wb_tab_meta_box', $_POST))
		{
			$tab_position=absint($_POST['wb_tab_tab_position']);
			update_post_meta($post_id, '_wb_tab_position', $tab_position);
		}
	}
	
	/**
	 *	@since 1.0.2
	 *	Register meta box for global tab custom post type
	 */
	public function register_meta_box()
	{
	    add_meta_box(
			'wb_tab_tab_position_meta_box',
			__('Tab position'), 
			array($this, '_tab_position_meta_box_html'),
			WB_TAB_POST_TYPE,
			'side',
			'default'
        );
	}

	/**
	 *	@since 1.0.2
	 *	Render HTML for tab position meta box
	 */
	public function _tab_position_meta_box_html( $post, $box)
	{
		$tab_position=Wb_Custom_Product_Tabs_For_Woocommerce::_get_global_tab_position($post->ID);
		include WB_TAB_ROOT_PATH.'admin/views/_global_tab_metabox.php';
	}

	/**
	* @since 1.0.9 
	* Global tabs, Add new product links on plugins page
	*/
	public function plugin_action_links($links)
	{
		$links[]='<a href="'.admin_url('edit.php?post_type='.WB_TAB_POST_TYPE).'">'.__('Product tabs', 'wb-custom-product-tabs-for-woocommerce').'</a>';

		$links[]='<a href="'.admin_url('post-new.php?post_type=product').'">'.__('Add new product', 'wb-custom-product-tabs-for-woocommerce').'</a>';
		return $links;
	}

}
